/*
 * Version: $RCSfile: VolaCheckGsm.cs,v $ - $Revision: 1.4 $ - $Date: 2009/02/17 09:32:30 $
 *  
 *  This file is part of VolaSmsPlus.
 *
 *   VolaSmsPlus is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published by
 *   the Free Software Foundation, either version 3 of the License.
 * 
 *   VolaSmsPlus is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with VolaSmsPlus.  If not, see <http://www.gnu.org/licenses/>.
**/


using System;
using System.Collections.Generic;
using System.Text;

//Classe la gestione dei GSM
namespace Vola.VolaSmsPlus
{

    internal class VolaCheckGsm
    {
        /// <summary>
        /// Struttura per i prefissi internazionali
        /// </summary>
        private static string[,] g_sPrefixCountries = null;
        /// <summary>
        /// Prefisso internazionale default
        /// </summary>
        private const string DefaultCountry = "+39";
       
        private const string FormatoGSMNumber = "";

        /// <summary>
        /// Formati GSM riconosciuti
        /// </summary>
        internal enum FormatGsm
        {
            ONLY_MSDN = 1,
            PLUS_COUNTRY_MSDN = 2,
            ZERO_CONUTRY_MSDN = 3,
            EXISTCOUNTRY_MSDN = 4
        }

        /// <summary>
        /// Verifica se il valore stringa di input  un numero GSM valido ed in caso che sia valido lo restituisce nel formato desiderato
        /// </summary>
        /// <param name="Cellulare">Valore stringa con il numero GSM da verificare</param>
        /// <param name="Formato">Formati</param>
        /// <returns>Stringa vuota se il numero GSM non  valido, stringa con il numero GSM nel formato desiderato altrimenti.</returns>
        internal static string CheckGSMNumber(string Cellulare, FormatGsm Formato)
        {
            string sMSISDN = "";
            int maxNumber;

            try
            {
                if (g_sPrefixCountries == null)
                    InitGsmPrefix();

                //if is date GSMNumber is not valid
                if (Cellulare.Length == 0)
                    return "";

                //cleaning GSMNumber string
                foreach (char carat in Cellulare)
                {
                    if (carat == '+' && sMSISDN.Length == 0)
                        sMSISDN += carat;
                    else
                        if ((int)carat > 47 && (int)carat < 58)
                            sMSISDN += carat;
                }
                //changing "00" in "+"
                if (sMSISDN.Substring(0, 2) == "00")
                    sMSISDN = "+" + sMSISDN.Substring(2);

                //Prefisso default combacia
                if (sMSISDN.Substring(0, DefaultCountry.Length) == DefaultCountry)
                {
                    if (sMSISDN.Length > 7 && sMSISDN.Length < 15)
                        return FormatGSMNumber(DefaultCountry, sMSISDN.Substring(DefaultCountry.Length), Formato, DefaultCountry);
                    else
                        return "";
                }

                //Prefisso in formato internazionale
                if (sMSISDN[0] == '+')
                {
                    for (short count = 0; count <= g_sPrefixCountries.Length; count++)
                    {
                        if (sMSISDN.Substring(0, g_sPrefixCountries[count, 0].Length) == g_sPrefixCountries[count, 0])
                        {
                            maxNumber = (11 + g_sPrefixCountries[count, 0].Length);
                            if (sMSISDN.Length > 7 && sMSISDN.Length < maxNumber)
                                return FormatGSMNumber(g_sPrefixCountries[count, 0], sMSISDN.Substring(g_sPrefixCountries[count, 0].Length), Formato, DefaultCountry);
                            else
                                return "";
                        }
                    }
                    return "";
                }
                else
                {

                    if (sMSISDN.Substring(0, DefaultCountry.Length - 1) == DefaultCountry.Substring(1))
                    {
                        if (sMSISDN.Length < 11) //H3G
                            return FormatGSMNumber("", sMSISDN, Formato, DefaultCountry);
                        else
                            if ((DefaultCountry + sMSISDN.Substring(DefaultCountry.Length - 1)).Length < 15)
                                return FormatGSMNumber("", sMSISDN.Substring(DefaultCountry.Length - 1), Formato, DefaultCountry);
                            else
                                return "";
                    }
                    else
                    {
                        if ((DefaultCountry + sMSISDN).Length > 7 && (DefaultCountry + sMSISDN).Length < 15)
                            return FormatGSMNumber("", sMSISDN,Formato, DefaultCountry);
                        else
                            return "";
                    }
                }

            }
            catch
            {
                return "";
            }
        }

        /// <summary>
        /// Restituisce il numero GSM nel formato desiderato
        /// </summary>
        /// <param name="Country">Prefisso internazionale</param>
        /// <param name="MSDN">Numero GSM</param>
        /// <param name="Formato">Formato GSM</param>
        /// <param name="DefaultCountry">Prefisso internazionale di deafault</param>
        /// <returns>Valore stringa con il numero GSM nel formato desiderato</returns>
        static private string FormatGSMNumber(string Country, string MSDN,FormatGsm Formato,string DefaultCountry)
        {
            switch (Formato){
                case FormatGsm.ONLY_MSDN:
                    return MSDN;                   
                case FormatGsm.PLUS_COUNTRY_MSDN:
                    if (Country.Length ==0)
                        return DefaultCountry + MSDN;
                    else
                        return Country + MSDN;                   
                case FormatGsm.ZERO_CONUTRY_MSDN:
                    if (Country.Length == 0)
                        return DefaultCountry.Replace("+","00") + MSDN;
                    else
                        return Country.Replace("+", "00") + MSDN;                   
                case FormatGsm.EXISTCOUNTRY_MSDN:
                    if (Country.Length == 0)
                        return MSDN;
                    else
                        return Country.Replace("+", "00") + MSDN;     
                default:
                    return "";
            }
                       
        }

        /// <summary>
        /// Riempe la lista dei prefissi internazionali
        /// </summary>
        private static void InitGsmPrefix()
        {
            g_sPrefixCountries = new string[244, 2];
            g_sPrefixCountries[0, 0] = "+1";
            g_sPrefixCountries[0, 1] = "Northern Mariana Islands";
            g_sPrefixCountries[1, 0] = "+1";
            g_sPrefixCountries[1, 1] = "United States Virgin Islands";
            g_sPrefixCountries[2, 0] = "+1";
            g_sPrefixCountries[2, 1] = "United States of America";
            g_sPrefixCountries[3, 0] = "+1";
            g_sPrefixCountries[3, 1] = "Turks and Caicos Islands";
            g_sPrefixCountries[4, 0] = "+1";
            g_sPrefixCountries[4, 1] = "Trinidad and Tobago";
            g_sPrefixCountries[5, 0] = "+1";
            g_sPrefixCountries[5, 1] = "Saint Vincent and the Grenadines";
            g_sPrefixCountries[6, 0] = "+1";
            g_sPrefixCountries[6, 1] = "Saint Lucia";
            g_sPrefixCountries[7, 0] = "+1";
            g_sPrefixCountries[7, 1] = "Anguilla";
            g_sPrefixCountries[8, 0] = "+1";
            g_sPrefixCountries[8, 1] = "Puerto Rico";
            g_sPrefixCountries[9, 0] = "+1";
            g_sPrefixCountries[9, 1] = "Montserrat";
            g_sPrefixCountries[10, 0] = "+1";
            g_sPrefixCountries[10, 1] = "Jamaica";
            g_sPrefixCountries[11, 0] = "+1";
            g_sPrefixCountries[11, 1] = "Bermuda";
            g_sPrefixCountries[12, 0] = "+1";
            g_sPrefixCountries[12, 1] = "Antigua and Barbuda";
            g_sPrefixCountries[13, 0] = "+1";
            g_sPrefixCountries[13, 1] = "Saint Kitts and Nevis";
            g_sPrefixCountries[14, 0] = "+1";
            g_sPrefixCountries[14, 1] = "Barbados";
            g_sPrefixCountries[15, 0] = "+1";
            g_sPrefixCountries[15, 1] = "Guam";
            g_sPrefixCountries[16, 0] = "+1";
            g_sPrefixCountries[16, 1] = "British Virgin Islands";
            g_sPrefixCountries[17, 0] = "+1";
            g_sPrefixCountries[17, 1] = "Canada";
            g_sPrefixCountries[18, 0] = "+1";
            g_sPrefixCountries[18, 1] = "Cayman Islands";
            g_sPrefixCountries[19, 0] = "+1";
            g_sPrefixCountries[19, 1] = "Dominica";
            g_sPrefixCountries[20, 0] = "+1";
            g_sPrefixCountries[20, 1] = "Dominican Republic";
            g_sPrefixCountries[21, 0] = "+1";
            g_sPrefixCountries[21, 1] = "Grenada and Carriacou";
            g_sPrefixCountries[22, 0] = "+1";
            g_sPrefixCountries[22, 1] = "Bahamas";

            g_sPrefixCountries[23, 0] = "+20";
            g_sPrefixCountries[23, 1] = "Egypt";
            g_sPrefixCountries[24, 0] = "+212";
            g_sPrefixCountries[24, 1] = "Morocco";
            g_sPrefixCountries[25, 0] = "+213";
            g_sPrefixCountries[25, 1] = "Algeria";
            g_sPrefixCountries[26, 0] = "+216";
            g_sPrefixCountries[26, 1] = "Tunisia";
            g_sPrefixCountries[27, 0] = "+218";
            g_sPrefixCountries[27, 1] = "Libya";
            g_sPrefixCountries[28, 0] = "+220";
            g_sPrefixCountries[28, 1] = "Gambia";
            g_sPrefixCountries[29, 0] = "+1221";
            g_sPrefixCountries[29, 1] = "Senegal";
            g_sPrefixCountries[30, 0] = "+222";
            g_sPrefixCountries[30, 1] = "Mauritania";
            g_sPrefixCountries[31, 0] = "+223";
            g_sPrefixCountries[31, 1] = "Mali";
            g_sPrefixCountries[32, 0] = "+224";
            g_sPrefixCountries[32, 1] = "Guinea";
            g_sPrefixCountries[33, 0] = "+225";
            g_sPrefixCountries[33, 1] = "Cte d'Ivoire";
            g_sPrefixCountries[34, 0] = "+226";
            g_sPrefixCountries[34, 1] = "Burkina Faso";
            g_sPrefixCountries[35, 0] = "+227";
            g_sPrefixCountries[35, 1] = "Niger";
            g_sPrefixCountries[36, 0] = "+228";
            g_sPrefixCountries[36, 1] = "Togolese Republic";
            g_sPrefixCountries[37, 0] = "+229";
            g_sPrefixCountries[37, 1] = "Benin";
            g_sPrefixCountries[38, 0] = "+230";
            g_sPrefixCountries[38, 1] = "Mauritius";
            g_sPrefixCountries[39, 0] = "+231";
            g_sPrefixCountries[39, 1] = "Liberia";
            g_sPrefixCountries[40, 0] = "+232";
            g_sPrefixCountries[40, 1] = "Sierra Leone";
            g_sPrefixCountries[41, 0] = "+233";
            g_sPrefixCountries[41, 1] = "Ghana";
            g_sPrefixCountries[42, 0] = "+234";
            g_sPrefixCountries[42, 1] = "Nigeria";
            g_sPrefixCountries[43, 0] = "+235";
            g_sPrefixCountries[43, 1] = "Chad";
            g_sPrefixCountries[44, 0] = "+236";
            g_sPrefixCountries[44, 1] = "Central African Republic";
            g_sPrefixCountries[45, 0] = "+237";
            g_sPrefixCountries[45, 1] = "Cameroon";
            g_sPrefixCountries[46, 0] = "+238";
            g_sPrefixCountries[46, 1] = "Cape Verde";
            g_sPrefixCountries[47, 0] = "+239";
            g_sPrefixCountries[47, 1] = "So Tome and Principe";
            g_sPrefixCountries[48, 0] = "+240";
            g_sPrefixCountries[48, 1] = "Equatorial Guinea";
            g_sPrefixCountries[49, 0] = "+241";
            g_sPrefixCountries[49, 1] = "Gabonese Republic";
            g_sPrefixCountries[50, 0] = "+242";
            g_sPrefixCountries[50, 1] = "Congo-Brazzaville";
            g_sPrefixCountries[51, 0] = "+243";
            g_sPrefixCountries[51, 1] = "Congo-Kinshasa";
            g_sPrefixCountries[52, 0] = "+244";
            g_sPrefixCountries[52, 1] = "Angola";
            g_sPrefixCountries[53, 0] = "+245";
            g_sPrefixCountries[53, 1] = "Guinea-Bissau";
            g_sPrefixCountries[54, 0] = "+246";
            g_sPrefixCountries[54, 1] = "Diego Garcia";
            g_sPrefixCountries[55, 0] = "+247";
            g_sPrefixCountries[55, 1] = "Ascension";
            g_sPrefixCountries[56, 0] = "+248";
            g_sPrefixCountries[56, 1] = "Seychelles";
            g_sPrefixCountries[57, 0] = "+249";
            g_sPrefixCountries[57, 1] = "Sudan";
            g_sPrefixCountries[58, 0] = "+250";
            g_sPrefixCountries[58, 1] = "Rwandese Republic";
            g_sPrefixCountries[59, 0] = "+251";
            g_sPrefixCountries[59, 1] = "Ethiopia";
            g_sPrefixCountries[60, 0] = "+252";
            g_sPrefixCountries[60, 1] = "Somali Democratic Republic";
            g_sPrefixCountries[61, 0] = "+253";
            g_sPrefixCountries[61, 1] = "Djibouti";
            g_sPrefixCountries[62, 0] = "+254";
            g_sPrefixCountries[62, 1] = "Kenya";
            g_sPrefixCountries[63, 0] = "+255";
            g_sPrefixCountries[63, 1] = "Tanzania";
            g_sPrefixCountries[64, 0] = "+256";
            g_sPrefixCountries[64, 1] = "Uganda";
            g_sPrefixCountries[65, 0] = "+257";
            g_sPrefixCountries[65, 1] = "Burundi";
            g_sPrefixCountries[66, 0] = "+258";
            g_sPrefixCountries[66, 1] = "Mozambique";
            g_sPrefixCountries[67, 0] = "+260";
            g_sPrefixCountries[67, 1] = "Zambia";
            g_sPrefixCountries[68, 0] = "+261";
            g_sPrefixCountries[68, 1] = "Madagascar";
            g_sPrefixCountries[69, 0] = "+262";
            g_sPrefixCountries[69, 1] = "Reunion";
            g_sPrefixCountries[70, 0] = "+263";
            g_sPrefixCountries[70, 1] = "Zimbabwe";
            g_sPrefixCountries[71, 0] = "+264";
            g_sPrefixCountries[71, 1] = "Namibia";
            g_sPrefixCountries[72, 0] = "+265";
            g_sPrefixCountries[72, 1] = "Malawi";
            g_sPrefixCountries[73, 0] = "+266";
            g_sPrefixCountries[73, 1] = "Lesotho";
            g_sPrefixCountries[74, 0] = "+267";
            g_sPrefixCountries[74, 1] = "Botswana";
            g_sPrefixCountries[75, 0] = "+268";
            g_sPrefixCountries[75, 1] = "Swaziland";
            g_sPrefixCountries[76, 0] = "+269";
            g_sPrefixCountries[76, 1] = "Comoros";
            g_sPrefixCountries[77, 0] = "+269";
            g_sPrefixCountries[77, 1] = "Mayotte";
            g_sPrefixCountries[78, 0] = "+27";
            g_sPrefixCountries[78, 1] = "South Africa";
            g_sPrefixCountries[79, 0] = "+290";
            g_sPrefixCountries[79, 1] = "Saint Helena";
            g_sPrefixCountries[80, 0] = "+291";
            g_sPrefixCountries[80, 1] = "Eritrea";
            g_sPrefixCountries[81, 0] = "+297";
            g_sPrefixCountries[81, 1] = "Aruba";
            g_sPrefixCountries[82, 0] = "+298";
            g_sPrefixCountries[82, 1] = "Faroe Islands";
            g_sPrefixCountries[83, 0] = "+299";
            g_sPrefixCountries[83, 1] = "Greenland";

            g_sPrefixCountries[84, 0] = "+30";
            g_sPrefixCountries[84, 1] = "Greece";
            g_sPrefixCountries[85, 0] = "+31";
            g_sPrefixCountries[85, 1] = "Netherlands";
            g_sPrefixCountries[86, 0] = "+32";
            g_sPrefixCountries[86, 1] = "Belgium";
            g_sPrefixCountries[87, 0] = "+33";
            g_sPrefixCountries[87, 1] = "France";
            g_sPrefixCountries[88, 0] = "+34";
            g_sPrefixCountries[88, 1] = "Spain";
            g_sPrefixCountries[89, 0] = "+350";
            g_sPrefixCountries[89, 1] = "Gibraltar";
            g_sPrefixCountries[90, 0] = "+351";
            g_sPrefixCountries[90, 1] = "Portugal";
            g_sPrefixCountries[91, 0] = "+352";
            g_sPrefixCountries[91, 1] = "Luxembourg";
            g_sPrefixCountries[92, 0] = "+353";
            g_sPrefixCountries[92, 1] = "Ireland";
            g_sPrefixCountries[93, 0] = "+354";
            g_sPrefixCountries[93, 1] = "Iceland";
            g_sPrefixCountries[94, 0] = "+355";
            g_sPrefixCountries[94, 1] = "Albania";
            g_sPrefixCountries[95, 0] = "+356";
            g_sPrefixCountries[95, 1] = "Malta";
            g_sPrefixCountries[96, 0] = "+357";
            g_sPrefixCountries[96, 1] = "Cyprus";
            g_sPrefixCountries[97, 0] = "+358";
            g_sPrefixCountries[97, 1] = "Finland";
            g_sPrefixCountries[98, 0] = "+359";
            g_sPrefixCountries[98, 1] = "Bulgaria";
            g_sPrefixCountries[99, 0] = "+36";
            g_sPrefixCountries[99, 1] = "Hungary";
            g_sPrefixCountries[100, 0] = "+370";
            g_sPrefixCountries[100, 1] = "Lithuania";
            g_sPrefixCountries[101, 0] = "+371";
            g_sPrefixCountries[101, 1] = "Latvia";
            g_sPrefixCountries[102, 0] = "+372";
            g_sPrefixCountries[102, 1] = "Estonia";
            g_sPrefixCountries[103, 0] = "+373";
            g_sPrefixCountries[103, 1] = "Moldova";
            g_sPrefixCountries[104, 0] = "+374";
            g_sPrefixCountries[104, 1] = "Armenia";
            g_sPrefixCountries[105, 0] = "+375";
            g_sPrefixCountries[105, 1] = "Belarus";
            g_sPrefixCountries[106, 0] = "+376";
            g_sPrefixCountries[106, 1] = "Andorra";
            g_sPrefixCountries[107, 0] = "+377";
            g_sPrefixCountries[107, 1] = "Monaco";
            g_sPrefixCountries[108, 0] = "+378";
            g_sPrefixCountries[108, 1] = "San Marino";
            g_sPrefixCountries[109, 0] = "+380";
            g_sPrefixCountries[109, 1] = "Ukraine";
            g_sPrefixCountries[110, 0] = "+381";
            g_sPrefixCountries[110, 1] = "Serbia";
            g_sPrefixCountries[110, 0] = "+382";
            g_sPrefixCountries[110, 1] = "Montenegro";
            g_sPrefixCountries[111, 0] = "+385";
            g_sPrefixCountries[111, 1] = "Croatia";
            g_sPrefixCountries[112, 0] = "+386";
            g_sPrefixCountries[112, 1] = "Slovenia";
            g_sPrefixCountries[113, 0] = "+387";
            g_sPrefixCountries[113, 1] = "Bosnia and Herzegovina";
            g_sPrefixCountries[114, 0] = "+388";
            g_sPrefixCountries[114, 1] = "Europe";
            g_sPrefixCountries[115, 0] = "+389";
            g_sPrefixCountries[115, 1] = "Macedonia";
            g_sPrefixCountries[116, 0] = "+39";
            g_sPrefixCountries[116, 1] = "Italy";
            g_sPrefixCountries[117, 0] = "+39";
            g_sPrefixCountries[117, 1] = "Vatican City State";

            g_sPrefixCountries[118, 0] = "+40";
            g_sPrefixCountries[118, 1] = "Romania";
            g_sPrefixCountries[119, 0] = "+41";
            g_sPrefixCountries[119, 1] = "Switzerland";
            g_sPrefixCountries[120, 0] = "+420";
            g_sPrefixCountries[120, 1] = "Czech Republic";
            g_sPrefixCountries[121, 0] = "+421";
            g_sPrefixCountries[121, 1] = "Slovak Republic";
            g_sPrefixCountries[122, 0] = "+423";
            g_sPrefixCountries[122, 1] = "Liechtenstein";
            g_sPrefixCountries[123, 0] = "+43";
            g_sPrefixCountries[123, 1] = "Austria";
            g_sPrefixCountries[124, 0] = "+44";
            g_sPrefixCountries[124, 1] = "United Kingdom of Great Britain";
            g_sPrefixCountries[125, 0] = "+45";
            g_sPrefixCountries[125, 1] = "Denmark";
            g_sPrefixCountries[126, 0] = "+46";
            g_sPrefixCountries[126, 1] = "Sweden";
            g_sPrefixCountries[127, 0] = "+47";
            g_sPrefixCountries[127, 1] = "Norway";
            g_sPrefixCountries[128, 0] = "+48";
            g_sPrefixCountries[128, 1] = "Poland";
            g_sPrefixCountries[129, 0] = "+49";
            g_sPrefixCountries[129, 1] = "Germany";

            g_sPrefixCountries[130, 0] = "+500";
            g_sPrefixCountries[130, 1] = "Falkland Islands";
            g_sPrefixCountries[131, 0] = "+501";
            g_sPrefixCountries[131, 1] = "Belize";
            g_sPrefixCountries[132, 0] = "+502";
            g_sPrefixCountries[132, 1] = "Guatemala";
            g_sPrefixCountries[133, 0] = "+503";
            g_sPrefixCountries[133, 1] = "El Salvador";
            g_sPrefixCountries[134, 0] = "+504";
            g_sPrefixCountries[134, 1] = "Honduras";
            g_sPrefixCountries[135, 0] = "+505";
            g_sPrefixCountries[135, 1] = "Nicaragua";
            g_sPrefixCountries[136, 0] = "+506";
            g_sPrefixCountries[136, 1] = "Costa Rica";
            g_sPrefixCountries[137, 0] = "+507";
            g_sPrefixCountries[137, 1] = "Panama";
            g_sPrefixCountries[138, 0] = "+508";
            g_sPrefixCountries[138, 1] = "Saint Pierre and Miquelon";
            g_sPrefixCountries[139, 0] = "+509";
            g_sPrefixCountries[139, 1] = "Haiti";
            g_sPrefixCountries[140, 0] = "+51";
            g_sPrefixCountries[140, 1] = "Peru";
            g_sPrefixCountries[141, 0] = "+52";
            g_sPrefixCountries[141, 1] = "Mexico";
            g_sPrefixCountries[142, 0] = "+53";
            g_sPrefixCountries[142, 1] = "Cuba";
            g_sPrefixCountries[143, 0] = "+54";
            g_sPrefixCountries[143, 1] = "Argentine Republic";
            g_sPrefixCountries[144, 0] = "+55";
            g_sPrefixCountries[144, 1] = "Brazil";
            g_sPrefixCountries[145, 0] = "+56";
            g_sPrefixCountries[145, 1] = "Chile";
            g_sPrefixCountries[146, 0] = "+57";
            g_sPrefixCountries[146, 1] = "Colombia";
            g_sPrefixCountries[147, 0] = "+58";
            g_sPrefixCountries[147, 1] = "Venezuela";
            g_sPrefixCountries[148, 0] = "+590";
            g_sPrefixCountries[148, 1] = "Guadeloupe";
            g_sPrefixCountries[149, 0] = "+591";
            g_sPrefixCountries[149, 1] = "Bolivia";
            g_sPrefixCountries[150, 0] = "+592";
            g_sPrefixCountries[150, 1] = "Guyana";
            g_sPrefixCountries[151, 0] = "+593";
            g_sPrefixCountries[151, 1] = "Ecuador";
            g_sPrefixCountries[152, 0] = "+594";
            g_sPrefixCountries[152, 1] = "French Guiana";
            g_sPrefixCountries[153, 0] = "+595";
            g_sPrefixCountries[153, 1] = "Paraguay";
            g_sPrefixCountries[154, 0] = "+596";
            g_sPrefixCountries[154, 1] = "Martinique";
            g_sPrefixCountries[155, 0] = "+597";
            g_sPrefixCountries[155, 1] = "Suriname";
            g_sPrefixCountries[156, 0] = "+598";
            g_sPrefixCountries[156, 1] = "Uruguay";
            g_sPrefixCountries[157, 0] = "+599";
            g_sPrefixCountries[157, 1] = "Netherlands Antilles";

            g_sPrefixCountries[158, 0] = "+60";
            g_sPrefixCountries[158, 1] = "Malaysia";
            g_sPrefixCountries[159, 0] = "+61";
            g_sPrefixCountries[159, 1] = "Australia";
            g_sPrefixCountries[160, 0] = "+61";
            g_sPrefixCountries[160, 1] = "Christmas Island";
            g_sPrefixCountries[161, 0] = "+61";
            g_sPrefixCountries[161, 1] = "Cocos";
            g_sPrefixCountries[162, 0] = "+62";
            g_sPrefixCountries[162, 1] = "Indonesia";
            g_sPrefixCountries[163, 0] = "+63";
            g_sPrefixCountries[163, 1] = "Philippines";
            g_sPrefixCountries[164, 0] = "+64";
            g_sPrefixCountries[164, 1] = "New Zealand";
            g_sPrefixCountries[165, 0] = "+65";
            g_sPrefixCountries[165, 1] = "Singapore";
            g_sPrefixCountries[166, 0] = "+66";
            g_sPrefixCountries[166, 1] = "Thailand";
            g_sPrefixCountries[167, 0] = "+670";
            g_sPrefixCountries[167, 1] = "East Timor";
            g_sPrefixCountries[168, 0] = "+672";
            g_sPrefixCountries[168, 1] = "Australian External Territories";
            g_sPrefixCountries[169, 0] = "+673";
            g_sPrefixCountries[169, 1] = "Brunei Darussalam";
            g_sPrefixCountries[170, 0] = "+674";
            g_sPrefixCountries[170, 1] = "Nauru";
            g_sPrefixCountries[171, 0] = "+675";
            g_sPrefixCountries[171, 1] = "Papua New Guinea";
            g_sPrefixCountries[172, 0] = "+676";
            g_sPrefixCountries[172, 1] = "Tonga";
            g_sPrefixCountries[173, 0] = "+677";
            g_sPrefixCountries[173, 1] = "Solomon Islands";
            g_sPrefixCountries[174, 0] = "+678";
            g_sPrefixCountries[174, 1] = "Vanuatu";
            g_sPrefixCountries[175, 0] = "+679";
            g_sPrefixCountries[175, 1] = "Fiji";
            g_sPrefixCountries[176, 0] = "+680";
            g_sPrefixCountries[176, 1] = "Palau";
            g_sPrefixCountries[177, 0] = "+681";
            g_sPrefixCountries[177, 1] = "Wallis and Futuna";
            g_sPrefixCountries[178, 0] = "+682";
            g_sPrefixCountries[178, 1] = "Cook Islands";
            g_sPrefixCountries[179, 0] = "+683";
            g_sPrefixCountries[179, 1] = "Niue";
            g_sPrefixCountries[180, 0] = "+684";
            g_sPrefixCountries[180, 1] = "American Samoa";
            g_sPrefixCountries[181, 0] = "+685";
            g_sPrefixCountries[181, 1] = "Samoa";
            g_sPrefixCountries[182, 0] = "+686";
            g_sPrefixCountries[182, 1] = "Kiribati";
            g_sPrefixCountries[183, 0] = "+687";
            g_sPrefixCountries[183, 1] = "New Caledonia";
            g_sPrefixCountries[184, 0] = "+688";
            g_sPrefixCountries[184, 1] = "Tuvalu";
            g_sPrefixCountries[185, 0] = "+689";
            g_sPrefixCountries[185, 1] = "French Polynesia";
            g_sPrefixCountries[186, 0] = "+690";
            g_sPrefixCountries[186, 1] = "Tokelau";
            g_sPrefixCountries[187, 0] = "+691";
            g_sPrefixCountries[187, 1] = "Micronesia";
            g_sPrefixCountries[188, 0] = "+692";
            g_sPrefixCountries[188, 1] = "Marshall Islands";

            g_sPrefixCountries[189, 0] = "+7";
            g_sPrefixCountries[189, 1] = "Kazakstan";
            g_sPrefixCountries[190, 0] = "+7";
            g_sPrefixCountries[190, 1] = "Russian Federation";

            g_sPrefixCountries[191, 0] = "+800";
            g_sPrefixCountries[191, 1] = "International Freephone Service";
            g_sPrefixCountries[192, 0] = "+808";
            g_sPrefixCountries[192, 1] = "International Shared Cost Servic";
            g_sPrefixCountries[193, 0] = "+81";
            g_sPrefixCountries[193, 1] = "Japan";
            g_sPrefixCountries[194, 0] = "+82";
            g_sPrefixCountries[194, 1] = "Korea";
            g_sPrefixCountries[195, 0] = "+84";
            g_sPrefixCountries[195, 1] = "Viet Nam";
            g_sPrefixCountries[196, 0] = "+850";
            g_sPrefixCountries[196, 1] = "Korea";
            g_sPrefixCountries[197, 0] = "+852";
            g_sPrefixCountries[197, 1] = "Hong Kong";
            g_sPrefixCountries[198, 0] = "+853";
            g_sPrefixCountries[198, 1] = "Macao";
            g_sPrefixCountries[199, 0] = "+855";
            g_sPrefixCountries[199, 1] = "Cambodia";
            g_sPrefixCountries[200, 0] = "+856";
            g_sPrefixCountries[200, 1] = "Lao People's Democratic Republic";
            g_sPrefixCountries[201, 0] = "+86";
            g_sPrefixCountries[201, 1] = "China";
            g_sPrefixCountries[202, 0] = "+870";
            g_sPrefixCountries[202, 1] = "Inmarsat Single Number Access";
            g_sPrefixCountries[203, 0] = "+871";
            g_sPrefixCountries[203, 1] = "Inmarsat Atlantic Ocean-East";
            g_sPrefixCountries[204, 0] = "+872";
            g_sPrefixCountries[204, 1] = "Inmarsat Pacific Ocean";
            g_sPrefixCountries[205, 0] = "+873";
            g_sPrefixCountries[205, 1] = "Inmarsat Indian Ocean";
            g_sPrefixCountries[206, 0] = "+874";
            g_sPrefixCountries[206, 1] = "Inmarsat Atlantic Ocean-West";
            g_sPrefixCountries[207, 0] = "+878";
            g_sPrefixCountries[207, 1] = "Universal Personal Telecommunica";
            g_sPrefixCountries[208, 0] = "+880";
            g_sPrefixCountries[208, 1] = "Bangladesh";
            g_sPrefixCountries[209, 0] = "+881";
            g_sPrefixCountries[209, 1] = "Global Mobile Satellite System";
            g_sPrefixCountries[210, 0] = "+882";
            g_sPrefixCountries[210, 1] = "International Networks";
            g_sPrefixCountries[211, 0] = "+886";
            g_sPrefixCountries[211, 1] = "Taiwan";

            g_sPrefixCountries[212, 0] = "+90";
            g_sPrefixCountries[212, 1] = "Turkey";
            g_sPrefixCountries[213, 0] = "+91";
            g_sPrefixCountries[213, 1] = "India";
            g_sPrefixCountries[214, 0] = "+92";
            g_sPrefixCountries[214, 1] = "Pakistan";
            g_sPrefixCountries[215, 0] = "+93";
            g_sPrefixCountries[215, 1] = "Afghanistan";
            g_sPrefixCountries[216, 0] = "+94";
            g_sPrefixCountries[216, 1] = "Sri Lanka";
            g_sPrefixCountries[217, 0] = "+95";
            g_sPrefixCountries[217, 1] = "Myanmar";
            g_sPrefixCountries[218, 0] = "+960";
            g_sPrefixCountries[218, 1] = "Maldives";
            g_sPrefixCountries[219, 0] = "+961";
            g_sPrefixCountries[219, 1] = "Lebanon";
            g_sPrefixCountries[220, 0] = "+962";
            g_sPrefixCountries[220, 1] = "Jordan";
            g_sPrefixCountries[221, 0] = "+963";
            g_sPrefixCountries[221, 1] = "Syrian Arab Republic";
            g_sPrefixCountries[222, 0] = "+964";
            g_sPrefixCountries[222, 1] = "Iraq";
            g_sPrefixCountries[223, 0] = "+965";
            g_sPrefixCountries[223, 1] = "Kuwait";
            g_sPrefixCountries[224, 0] = "+966";
            g_sPrefixCountries[224, 1] = "Saudi Arabia";
            g_sPrefixCountries[225, 0] = "+967";
            g_sPrefixCountries[225, 1] = "Yemen";
            g_sPrefixCountries[226, 0] = "+968";
            g_sPrefixCountries[226, 1] = "Oman";
            g_sPrefixCountries[227, 0] = "+970";
            g_sPrefixCountries[227, 1] = "Palestine";
            g_sPrefixCountries[228, 0] = "+971";
            g_sPrefixCountries[228, 1] = "United Arab Emirates";
            g_sPrefixCountries[229, 0] = "+972";
            g_sPrefixCountries[229, 1] = "Israel";
            g_sPrefixCountries[230, 0] = "+973";
            g_sPrefixCountries[230, 1] = "Bahrain";
            g_sPrefixCountries[231, 0] = "+974";
            g_sPrefixCountries[231, 1] = "Qatar";
            g_sPrefixCountries[232, 0] = "+975";
            g_sPrefixCountries[232, 1] = "Bhutan";
            g_sPrefixCountries[233, 0] = "+976";
            g_sPrefixCountries[233, 1] = "Mongolia";
            g_sPrefixCountries[234, 0] = "+977";
            g_sPrefixCountries[234, 1] = "Nepal";
            g_sPrefixCountries[235, 0] = "+979";
            g_sPrefixCountries[235, 1] = "International Premium Rate Servi";
            g_sPrefixCountries[236, 0] = "+98";
            g_sPrefixCountries[236, 1] = "Iran";
            g_sPrefixCountries[237, 0] = "+991";
            g_sPrefixCountries[237, 1] = "International Public Corresponde";
            g_sPrefixCountries[238, 0] = "+992";
            g_sPrefixCountries[238, 1] = "Tajikistan";
            g_sPrefixCountries[239, 0] = "+993";
            g_sPrefixCountries[239, 1] = "Turkmenistan";
            g_sPrefixCountries[240, 0] = "+994";
            g_sPrefixCountries[240, 1] = "Azerbaijani Republic";
            g_sPrefixCountries[241, 0] = "+995";
            g_sPrefixCountries[241, 1] = "Georgia";
            g_sPrefixCountries[242, 0] = "+996";
            g_sPrefixCountries[242, 1] = "Kyrgyz Republic";
            g_sPrefixCountries[243, 0] = "+998";
            g_sPrefixCountries[243, 1] = "Uzbekistan";

        }
    }
}